@@ -15,7 +15,7 @@ from . import vtk
 from . import geojson
 from . import xyfile
 from . import _shpfuncs
-from .. import crs
+from .. import crs as kcrs
 
 from collections import deque
 from .metadata import Metadata
@@ -43,7 +43,7 @@ class Geometry(object):
     Multipoints and subclasses thereof. """
     _geotype = None
 
-    def __init__(self, crs=crs.CARTESIAN):
+    def __init__(self, crs=kcrs.CARTESIAN):
         self.properties = {}
         self._crs = crs
         return
@@ -51,7 +51,7 @@ class Geometry(object):
     def _distance(self, pos0, pos1):
         """ Generic method for calculating distance between positions that
         respects CRS """
-        if self._crs == crs.CARTESIAN:
+        if self._crs == kcrs.CARTESIAN:
             dist = _vecgeo.distance((pos0.x, pos0.y), (pos1.x, pos1.y))
         elif PYPROJ:
             _, _, dist = geod.inv(pos0.x, pos0.y, pos1.x, pos1.y, radians=False)
@@ -149,13 +149,13 @@ class Point(Geometry):
         if self.coordsxy() == other.coordsxy():
             return np.nan
 
-        if self._crs == crs.LONLAT and other._crs == crs.LONLAT:
+        if self._crs == kcrs.LONLAT and other._crs == kcrs.LONLAT:
             if not PYPROJ:
-                raise CRSError("Azimuth on LONLAT grids requires pyproj")
+                raise CRSError("Non-cartesian points require pyproj")
             az1, _, _ = geod.inv(self.x, self.y, other.x, other.y)
             return az1 * math.pi / 180.0
 
-        elif self._crs == crs.CARTESIAN and other._crs == crs.CARTESIAN:
+        elif self._crs == kcrs.CARTESIAN and other._crs == kcrs.CARTESIAN:
             dx = other.x - self.x
             dy = other.y - self.y
 
@@ -183,9 +183,32 @@ class Point(Geometry):
             raise CRSError("Azimuth undefined for points in CRS {0} and "
                            "{1}".format(self._crs, other._crs))
 
-    def walk(self, distance, bearing, azimuth=0.0, spherical=False):
-        """ Wraps walk() """
-        return walk(self, distance, bearing, azimuth=0.0, spherical=False)
+    def walk(self, distance, direction):
+        """ Returns the point reached when moving in a given direction for
+        a given distance from a specified starting location.
+
+            distance (float): distance to walk
+            direction (float): horizontal walk direction in radians
+        """
+        if self._crs == kcrs.CARTESIAN:
+            dx = distance * math.cos(direction)
+            dy = distance * math.sin(direction)
+
+            if self.rank == 2:
+                return Point((self.x+dx, self.y+dy),
+                             properties=self.properties, data=self.data, crs=self._crs)
+            elif self.rank == 3:
+                return Point((self.x+dx, self.y+dy, self.z),
+                             properties=self.properties, data=self.data, crs=self._crs)
+
+        elif PYPROJ:
+            (x, y, backaz) = geod.fwd(self.x, self.y, direction*180.0/math.pi,
+                                      distance, radians=False)
+            return Point((x, y), properties=self.properties, data=self.data,
+                         crs=self._crs)
+
+        else:
+            raise CRSError("Non-cartesian points require pyproj")
 
     def distance(self, other):
         """ Returns a distance to another Point. If the coordinate system is
@@ -202,8 +225,8 @@ class Point(Geometry):
     def greatcircle(self, other):
         """ Return the great circle distance between two geographical points. """
         if not PYPROJ:
-            raise CRSError("Great circle computations require pyproj")
-        if not (self._crs == crs.LONLAT and other._crs == crs.LONLAT):
+            raise CRSError("Non-cartesian points require pyproj")
+        if not (self._crs == kcrs.LONLAT and other._crs == kcrs.LONLAT):
             raise CRSError("Great circle distances require both points to be "
                            "in geographical coordinates")
         az1, az2, dist = geod.inv(self.x, self.y, other.x, other.y, radians=False)
@@ -1027,36 +1050,6 @@ def greatcircle(pta, ptb, method="vicenty"):
     return distance
 
 
-def walk(start_pt, distance, bearing, azimuth=0.0, spherical=False):
-    """ Returns the point reached when moving in a given direction for
-    a given distance from a specified starting location.
-
-        start_pt (point): starting location
-        distance (float): distance to walk
-        bearing (float): horizontal walk direction in radians
-        azimuth (float): vertical walk direction in radians
-
-        [NOT IMPLEMENTED]
-        spherical (bool): use a spherical reference surface (globe)
-    """
-    if azimuth != 0.0:
-        distxy = distance * math.sin(azimuth)
-        dz = distance * math.cos(azimuth)
-    else:
-        distxy = distance
-        dz = 0.0
-    dx = distxy * math.sin(bearing)
-    dy = distxy * math.cos(bearing)
-
-    if start_pt.rank == 3:
-        return Point((start_pt.x+dx, start_pt.y+dy, start_pt.z+dz))
-    elif start_pt.rank == 2:
-        if azimuth != 0:
-            sys.stderr.write("Warning: start_pt has rank 2 but azimuth is "
-                             "nonzero\n")
-        return Point((start_pt.x+dx, start_pt.y+dy))
-
-
 def sortby(A, B):
     """ Sort a list A by the values in an ordered list B. """
     if len(A) != len(B):
@@ -1088,25 +1081,3 @@ def points_to_multipoint(points):
 
     return Multipoint(vertices, data=ptdata, crs=crs)
 
-def tighten(X, Z):
-    """ Return a list of corrected measurements from observations of
-    topography across a cross-section. The inputs are equal length
-    lists of observed distance and elevation.
-
-    Usage scenario: While surveying transects using a tape, the tape
-    is anchored to the topographical surface, rather than directly
-    between same-height endpoints.
-    """
-    if len(X) != len(Z):
-        raise GGeoError('Observation vectors must have equal length')
-
-    DZ = [z2-z1 for z2,z1 in zip(Z[1:], Z[:-1])]
-    DX = [x2-x1 for x2,x1 in zip(X[1:], X[:-1])]
-
-    DXt = [math.sqrt(x*x-z*z) for x,z in zip(DX, DZ)]
-
-    Xt = map(lambda i: sum(DXt[:i]) + X[0], range(len(DX)))
-
-    return zip(Xt, Z)
-
-
